class WrongSortMethodException(Exception):
    pass


class NoBoardProvidedException(Exception):
    pass


class InvalidThreadException(Exception):
    pass


class InvalidBoardIdException(Exception):
    pass
